# ⬇️ Downloading Library (BETA)

First browse to the GitHub repo.

{% embed url="https://github.com/Jordan-Prescott/odin_api" %}

Next, click the green '_<> Code'_ button and then '_Download ZIP'._

<figure><img src="../../.gitbook/assets/image (2).png" alt=""><figcaption></figcaption></figure>

Once the code is downloaded, extract the files from the zipped file and locate the folder _'odin\_api'_ the file _'requirements.txt'._ These are the only files and folders you need to use the library, the others can be removed.&#x20;

<figure><img src="../../.gitbook/assets/image (3).png" alt=""><figcaption></figcaption></figure>

Staying in the same folder opens a new machine terminal, one method to do this is from your folder view click the blue file in the top right-hand corner and select 'O_pen Windows PowerShell'._ Next you need to install the requirements for the library, run the below command to do this.

```python
pip install -r requirements.txt
```

Finally, place that folder where you would like to write code that uses the library and import the library in your Python files.&#x20;

<figure><img src="../../.gitbook/assets/image (4).png" alt=""><figcaption></figcaption></figure>

{% hint style="info" %}
While the library is in development this is the current way to use it. Please note this will change once version 0.1.0 is released.
{% endhint %}
